@@ -445,9 +445,10 @@ def main(args=sys.argv[1:]):
                       help='print the variables in a template')
     entry_points = get_entry_points()
     if entry_points:
-        parser.add_option('--list-templates', dest='list_templates',
+        parser.add_option('--list', '--list-templates',
+                          dest='list_templates',
                           action='store_true', default=False,
-                          help="list installed MakeItSo! templates")
+                          help="list installed templates")
 
     options, args = parser.parse_args(args)
 
